.\"	$NetBSD: lwres_packet.3,v 1.6.8.1 2017/06/21 18:03:49 snj Exp $
.\"
.\" Copyright (C) 2004, 2005, 2007, 2014-2016 Internet Systems Consortium, Inc. ("ISC")
.\" Copyright (C) 2000, 2001 Internet Software Consortium.
.\" 
.\" Permission to use, copy, modify, and/or distribute this software for any
.\" purpose with or without fee is hereby granted, provided that the above
.\" copyright notice and this permission notice appear in all copies.
.\" 
.\" THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
.\" REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
.\" AND FITNESS. IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
.\" INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
.\" LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
.\" OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
.\" PERFORMANCE OF THIS SOFTWARE.
.\"
.hy 0
.ad l
'\" t
.\"     Title: lwres_packet
.\"    Author: 
.\" Generator: DocBook XSL Stylesheets v1.78.1 <http://docbook.sf.net/>
.\"      Date: 2007-06-18
.\"    Manual: BIND9
.\"    Source: ISC
.\"  Language: English
.\"
.TH "LWRES_PACKET" "3" "2007\-06\-18" "ISC" "BIND9"
.\" -----------------------------------------------------------------
.\" * Define some portability stuff
.\" -----------------------------------------------------------------
.\" ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.\" http://bugs.debian.org/507673
.\" http://lists.gnu.org/archive/html/groff/2009-02/msg00013.html
.\" ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.ie \n(.g .ds Aq \(aq
.el       .ds Aq '
.\" -----------------------------------------------------------------
.\" * set default formatting
.\" -----------------------------------------------------------------
.\" disable hyphenation
.nh
.\" disable justification (adjust text to left margin only)
.ad l
.\" -----------------------------------------------------------------
.\" * MAIN CONTENT STARTS HERE *
.\" -----------------------------------------------------------------
.SH "NAME"
lwres_lwpacket_renderheader, lwres_lwpacket_parseheader \- lightweight resolver packet handling functions
.SH "SYNOPSIS"
.sp
.ft B
.nf
#include <lwres/lwpacket\&.h>
.fi
.ft
.HP \w'lwres_result_t\ lwres_lwpacket_renderheader('u
.BI "lwres_result_t lwres_lwpacket_renderheader(lwres_buffer_t\ *" "b" ", lwres_lwpacket_t\ *" "pkt" ");"
.HP \w'lwres_result_t\ lwres_lwpacket_parseheader('u
.BI "lwres_result_t lwres_lwpacket_parseheader(lwres_buffer_t\ *" "b" ", lwres_lwpacket_t\ *" "pkt" ");"
.SH "DESCRIPTION"
.PP
These functions rely on a
\fBstruct lwres_lwpacket\fR
which is defined in
lwres/lwpacket\&.h\&.
.PP
.if n \{\
.RS 4
.\}
.nf
typedef struct lwres_lwpacket lwres_lwpacket_t;
.fi
.if n \{\
.RE
.\}
.PP
.if n \{\
.RS 4
.\}
.nf
struct lwres_lwpacket {
        lwres_uint32_t          length;
        lwres_uint16_t          version;
        lwres_uint16_t          pktflags;
        lwres_uint32_t          serial;
        lwres_uint32_t          opcode;
        lwres_uint32_t          result;
        lwres_uint32_t          recvlength;
        lwres_uint16_t          authtype;
        lwres_uint16_t          authlength;
};
.fi
.if n \{\
.RE
.\}
.PP
The elements of this structure are:
.PP
\fBlength\fR
.RS 4
the overall packet length, including the entire packet header\&. This field is filled in by the lwres_gabn_*() and lwres_gnba_*() calls\&.
.RE
.PP
\fBversion\fR
.RS 4
the header format\&. There is currently only one format,
\fBLWRES_LWPACKETVERSION_0\fR\&. This field is filled in by the lwres_gabn_*() and lwres_gnba_*() calls\&.
.RE
.PP
\fBpktflags\fR
.RS 4
library\-defined flags for this packet: for instance whether the packet is a request or a reply\&. Flag values can be set, but not defined by the caller\&. This field is filled in by the application wit the exception of the LWRES_LWPACKETFLAG_RESPONSE bit, which is set by the library in the lwres_gabn_*() and lwres_gnba_*() calls\&.
.RE
.PP
\fBserial\fR
.RS 4
is set by the requestor and is returned in all replies\&. If two or more packets from the same source have the same serial number and are from the same source, they are assumed to be duplicates and the latter ones may be dropped\&. This field must be set by the application\&.
.RE
.PP
\fBopcode\fR
.RS 4
indicates the operation\&. Opcodes between 0x00000000 and 0x03ffffff are reserved for use by the lightweight resolver library\&. Opcodes between 0x04000000 and 0xffffffff are application defined\&. This field is filled in by the lwres_gabn_*() and lwres_gnba_*() calls\&.
.RE
.PP
\fBresult\fR
.RS 4
is only valid for replies\&. Results between 0x04000000 and 0xffffffff are application defined\&. Results between 0x00000000 and 0x03ffffff are reserved for library use\&. This field is filled in by the lwres_gabn_*() and lwres_gnba_*() calls\&.
.RE
.PP
\fBrecvlength\fR
.RS 4
is the maximum buffer size that the receiver can handle on requests and the size of the buffer needed to satisfy a request when the buffer is too large for replies\&. This field is supplied by the application\&.
.RE
.PP
\fBauthtype\fR
.RS 4
defines the packet level authentication that is used\&. Authorisation types between 0x1000 and 0xffff are application defined and types between 0x0000 and 0x0fff are reserved for library use\&. Currently these are not used and must be zero\&.
.RE
.PP
\fBauthlen\fR
.RS 4
gives the length of the authentication data\&. Since packet authentication is currently not used, this must be zero\&.
.RE
.PP
The following opcodes are currently defined:
.PP
\fBNOOP\fR
.RS 4
Success is always returned and the packet contents are echoed\&. The lwres_noop_*() functions should be used for this type\&.
.RE
.PP
\fBGETADDRSBYNAME\fR
.RS 4
returns all known addresses for a given name\&. The lwres_gabn_*() functions should be used for this type\&.
.RE
.PP
\fBGETNAMEBYADDR\fR
.RS 4
return the hostname for the given address\&. The lwres_gnba_*() functions should be used for this type\&.
.RE
.PP
\fBlwres_lwpacket_renderheader()\fR
transfers the contents of lightweight resolver packet structure
\fBlwres_lwpacket_t\fR\fI*pkt\fR
in network byte order to the lightweight resolver buffer,
\fI*b\fR\&.
.PP
\fBlwres_lwpacket_parseheader()\fR
performs the converse operation\&. It transfers data in network byte order from buffer
\fI*b\fR
to resolver packet
\fI*pkt\fR\&. The contents of the buffer
\fIb\fR
should correspond to a
\fBlwres_lwpacket_t\fR\&.
.SH "RETURN VALUES"
.PP
Successful calls to
\fBlwres_lwpacket_renderheader()\fR
and
\fBlwres_lwpacket_parseheader()\fR
return
\fBLWRES_R_SUCCESS\fR\&. If there is insufficient space to copy data between the buffer
\fI*b\fR
and lightweight resolver packet
\fI*pkt\fR
both functions return
\fBLWRES_R_UNEXPECTEDEND\fR\&.
.SH "AUTHOR"
.PP
\fBInternet Systems Consortium, Inc\&.\fR
.SH "COPYRIGHT"
.br
Copyright \(co 2004, 2005, 2007, 2014-2016 Internet Systems Consortium, Inc. ("ISC")
.br
Copyright \(co 2000, 2001 Internet Software Consortium.
.br
